@@ -10,7 +10,7 @@ use Object::Lazy::Ref; # overwrite CORE::GLOBAL::ref
 
 my $object = Object::Lazy->new({
     build => sub {
-        return RealClass->new();
+        return RealClass->new;
     },
     # set the ref answer
     ref   => 'RealClass',
@@ -43,10 +43,10 @@ __END__
 output:
 
 RealClass = ref $object;
-RealClass object built at ../lib/Object/Lazy.pm line 33
-    Object::Lazy::BUILD_OBJECT() called at D:/Perl/site/lib/Try/Tiny.pm line 76
-    eval {...} called at D:/Perl/site/lib/Try/Tiny.pm line 67
-    Try::Tiny::try('CODE(...)', 'Try::Tiny::Catch=REF(...)') called at ../lib/Object/Lazy.pm line 37
-    Object::Lazy::BUILD_OBJECT('Object::Lazy=HASH(...)', 'REF(...)') called at ../lib/Object/Lazy.pm line 108
-    Object::Lazy::can('Object::Lazy=HASH(...)', 'new') called at 06_ref.pl line 27
+RealClass object built at ../lib/Object/Lazy.pm line 35.
+    Object::Lazy::try {...} () called at D:/Perl/site/lib/Try/Tiny.pm line 81
+    eval {...} called at D:/Perl/site/lib/Try/Tiny.pm line 72
+    Try::Tiny::try(CODE(...), Try::Tiny::Catch=REF(...)) called at ../lib/Object/Lazy.pm line 39
+    Object::Lazy::BUILD_OBJECT(RealClass=HASH(...), REF(...)) called at ../lib/Object/Lazy.pm line 110
+    Object::Lazy::can(RealClass=HASH(...), "new") called at 06_ref.pl line 27
 CODE(...) = $object->can('new')
